﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.SharePoint.Client;
using Visifire.Charts;

namespace SilverlightOM
{
    public partial class MainPage : UserControl
    {
        Web web;
        List tasks;
        //ListItemCollection items;
        ListItemCollection collListItem;

        public MainPage() { InitializeComponent();

        ClientContext clientContext = new ClientContext("http://msp-niverson10/spsat");
        web = clientContext.Web;
        tasks = web.Lists.GetByTitle("Tasks");

        CamlQuery camlQuery = new CamlQuery();
        camlQuery.ViewXml = "<View><RowLimit>1000</RowLimit></View>";

        collListItem = tasks.GetItems(camlQuery);

        clientContext.Load(collListItem,
            items => items.IncludeWithDefaultProperties());


        clientContext.ExecuteQueryAsync(onQuerySucceeded, onQueryFailed);

        }   
              
        
        private void onQuerySucceeded(object sender, ClientRequestSucceededEventArgs args) {
            UpdateUIMethod updateUI = CreateChart;
            this.Dispatcher.BeginInvoke(updateUI);

        }   
        
        private void onQueryFailed(object sender, ClientRequestFailedEventArgs args) 
        {

            MessageBox.Show("Request failed. " + args.Message + "\n" + args.StackTrace);
        }

        private delegate void UpdateUIMethod();



        /// <summary>
        /// Function to create a chart
        /// </summary>
        public void CreateChart()
        {
            // Create a new instance of Chart
            Chart chart = new Chart();

            //MessageBox.Show("hi");
            // Set the chart width and height
            chart.Width = 500;
            chart.Height = 250;

            // Create a new instance of Title
            Title title = new Title();

            // Set title property
            title.Text = "Tasks by Department";

            // Add title to Titles collection
            chart.Titles.Add(title);

            // Create a new instance of DataSeries
            DataSeries dataSeries = new DataSeries();

            // Set DataSeries property
            dataSeries.RenderAs = RenderAs.Pie;

            // Create a DataPoint
            DataPoint dataPoint;


            // Boring stuff I should really use LINQ for
            Dictionary<string, int> deptCounts = new Dictionary<string, int>();
            foreach (ListItem item in collListItem)
            {
                string dept = item.FieldValues["Department"] as string;
                if (!deptCounts.ContainsKey(dept))
                    deptCounts.Add(dept, 1);
                else
                    deptCounts[dept] = deptCounts[dept] + 1;

            }

            // Bind the Data Points
            foreach (string key in deptCounts.Keys)
            {
                dataPoint = new DataPoint();
                dataPoint.YValue = deptCounts[key];
                dataPoint.Name = key;
                dataPoint.LabelText = key;
                dataPoint.LabelEnabled = true;
                dataSeries.DataPoints.Add(dataPoint);
            }

            // Add dataSeries to Series collection.
            chart.Series.Add(dataSeries);

            // Add chart to LayoutRoot
            LayoutRoot.Children.Add(chart);
        }

        /// <summary>
        /// Create a random class variable
        /// </summary>
        Random rand = new Random(DateTime.Now.Millisecond);
      
    }

}
